/* -------------------------------------------------------------------
 *
 *	File: AdacException.cpp
 *
 *	Date: 99/05/28
 *
 *	Author: Jrgen Schober, Point Design Software
 *
 *	Description: Exception handling for msql++
 *			and ADAC (Amiga Data Access Class, based
 *			on msql)
 *
 * ------------------------------------------------------------------- */

#include <stdio.h>
#include <string.h>
#include <intuition/intuition.h>

#include <clib/intuition_protos.h>

#include <adac/AdacException.h>

char* AdacExceptionArray[] =
{
	"Unknown Error",
	"Function not implemented",
	"Generell mSQL Error"
};

AdacException::AdacException(int code)
{
	if (code < 0 || code > ADACE_NO_ERROR)
		code = ADACE_UNKNOWN_ERROR;

	exc_Hint = NULL;
	exc_Code = code;
	exc_Text = AdacExceptionArray[code];
}

void AdacException::Print(char *title)
{
	if (title)
		if (exc_Hint)
			printf("%s %s (%s)\n",title,exc_Text, exc_Hint);
		else
			printf("%s %s\n",title,exc_Text);
	else
		if (exc_Hint)
			printf("ADAC Exception: %s (%s)\n",exc_Text,exc_Hint);
		else
			printf("ADAC Exception: %s \n",exc_Text);
}

int AdacException::Warn(char *title,char *buttons)
{
    EasyStruct EsReq =
    {
        sizeof(struct EasyStruct),
        0,
        "ADAC Exception",
        NULL,
        "Continue"
    };

	if (title)
		EsReq.es_Title = title;
	if (buttons)
		EsReq.es_GadgetFormat = buttons;

	char *t;

	if (exc_Hint)
	{
 		t = new char[strlen(exc_Text)+strlen(exc_Hint) + 4];
 		sprintf(t,"%s\n(%s)",exc_Text,exc_Hint);
	}
	else
	{
 		t = new char[strlen(exc_Text)+1];
		sprintf(t,"%s",exc_Text);
	}

	EsReq.es_TextFormat = t;

    int r = EasyRequestArgs(NULL,(EasyStruct*)&EsReq,NULL,NULL);

	if (t) delete t;

	return r;
}

int AdacException::Warn(char *buttons)
{
	return Warn(NULL,buttons);
}

